from TW.API import *
import Interface
from weakref import WeakValueDictionary

__all__ = [
    'WeakCache', 'PermanentCache', 'NoCache',
]


class ICache(Interface.Base):

    """Cache - a restricted subset of the standard dictionary interface"""

    def get(key, default=None):
        """Retrieve object denoted by 'key', or 'default' if not found
        
            Note that cache implementations do not have to guarantee that
            'get()' will return items placed in the cache, or indeed
            ever return anything other than 'default'.  For example, the
            'NoCache' type always returns 'default'.
        """

    def __setitem__(key,value):
        """Save 'value' in the cache under 'key'

            Note that no particular lifetime for 'value' remaining in the
            cache is required.  For example, the 'NoCache' type implements
            this method as a no-op.
        """

    def clear():
        """Clear cache contents, if any"""









class CacheBase(object):

    __metaclasses__ = OnceClass, Meta.AssertInterfaces
    __implements__  = ICache


class WeakCache(CacheBase, WeakValueDictionary):

    """Keeps items in cache as long as they are in use elsewhere"""
    
    def __init__(self, cacheOwner, *args):
        super(WeakCache,self).__init__()


class PermanentCache(CacheBase, dict):

    """Keeps items in cache until explicitly cleared"""
    
    def __new__(klass, cacheOwner, *args):
        return super(PermanentCache,klass).__new__(klass)

    def __init__(self, cacheOwner, *args):
        pass


class NoCache(CacheBase):

    """Never keeps anything in cache"""
    
    def __init__(self, cacheOwner, *args):  pass
    def get(self, key, default=None):       return default
    def __setitem__(self, key, value):      pass
    def clear(self):                        pass








setupModule()
