"""Interfaces for TransWarp Database components - very rudimentary so far"""

from TW.API import *
import Interface

__all__ = [
    'ITypeImpl', 'ITypeManager', 'ReadWriteNotDeclared', 'TransactionReadOnly'
]


# XXX These exceptions need more fleshing out...

class ReadWriteNotDeclared(Exception): pass
class TransactionReadOnly(Exception): pass


class ITypeImpl(SEF.IService):

    def _changedField(record, fieldName, oldValue, newValue):
        """Return 'newValue' to allow change to proceed, 'oldValue' to veto
        the change, or any other value to force that value to be used instead.
        """

    def _saveRecord(record):
        """Write out any of record's dirty fields"""

    def isSubtypeOf(otherType):
        """Return true if this type is a subtype of 'otherType'"""
        
    allTypeNames = Interface.Attribute(
        """A kjSet() of this type's supertype names, including this type"""
    )

    allSubtypeNames = Interface.Attribute(
        """A kjSet() of this type's subtype names, including this type"""
    )





class ITypeManager(SEF.IService):

    """An object which records delegate their management to"""
    
    def _loadDataFor(record, typeName):
        """Retrieve data for type 'typeName' and load it into 'record',
            updating record's typeMap as appropriate (to reflect types
            found and not found).  NOTE: Should also erase unused keys, if not
            overwriting them!"""

    def _setTypeFor(record, typeName):
        """Ensure that record is of type 'typeName'; should load default values,
        mark the applicable fields as dirty, and the appropriate types as being
        valid.  Note that this implies '_setTypeFor()' on all supertypes of the
        selected type."""


    def _unsetTypeFor(record, typeName):
        """Ensure that record is not of type 'typeName'; should remove fields
        from the record, and mark the appropriate types as not being valid.
        Note that this implies '_unsetTypeFor()' on all subtypes of the selected
        type."""


    def _cacheRecord(record):
        """Ensure that record is cached under (only) the correct keys"""

    def _getType(typeName):
        """Return the ITypeImpl object corresponding to 'typeName'"""

    baseTypeName = Interface.Attribute(
        """Name of type from which all types served by this manager inherit"""
    )

    keyFieldNames = Interface.Attribute(
        """kjSet() of all field names used as part of caching keys"""
    )




class IDatabase(SEF.IService):

    def flushUpdates():
        """Instruct all queued records to flush their updates"""
        
    def queueForUpdate(record):
        """Queue 'record' for later update flushing"""
        
    def _register(record):
        """Register 'record' with the transaction manager as having changed"""


setupModule()
