"""Extension to DataModel for LDAP record types - a work in progress"""

from TW.API import *
from TW.Database import DataModel
from kjbuckets import *

__bases__ = DataModel,

def normalizeDN(dn):
    from ldap import explode_dn
    dn = explode_dn(dn.lower())
    return ','.join(
        ['='.join([x.strip() for x in y.split('=',1)]) for y in key]
    )



























class RecordType:

    searchScope = 2
    baseDN = None
    searchFilter = None
    loadAttrs = None
    requiredObjectClassSet = kjSet()


    def _loadDataFor(self, record, typeName=None):
    
        """Define in subclasses to read data into record"""

        objectClasses = record.objectClasses

        # If data already is loaded and it doesn't have the right classes
        if objectClasses and (self.requiredObjectClassSet - objectClasses):
            record.updateTypeMap(self,0)
            return

        # Else load the data
        conn = self.getService('LDAPConnection')

        if record.dn:
            results = conn(record.dn, 0, 
                self.searchFilter, self.loadAttrs)
        else:            
            results = conn(self.baseDN, self.searchScope, 
                record.makeFilter(self.searchFilter), self.loadAttrs)

        assert len(results)<2, ("More than one LDAP entry found for %s" % record)

        if results:
            record.loadDefaults(results[0])
            record.updateTypeMap(self,1)
        else:
            record.updateTypeMap(self,0)




    def _setTypeFor(self, record, typeName=None):
        # XXX Add objectclasses, default values for fields
        # XXX Needs way to create DN if adding
        raise NotImplementedError

    def _unsetTypeFor(self, record, typeName=None):
        # XXX Remove which objectclasses & del which fields?
        raise NotImplementedError

    def _saveRecord(self, record):
        # XXX Needs to diff fields and issue mods
        raise NotImplementedError


    def _changedField(self, record, fieldName, oldValue, newValue):

        # XXX Needs to check modification of dn or fields which are in dn

        record.ensureQueued     # ensure record is queued for update
        return newValue





















class Record:

    dn = None
    objectClasses = None        

    def __init__(self, *args, **kw):
        __proceed__(self,*args,**kw)
        self.before = {}


    def loadData(self, mapping={}, **kw):
    
        data = {}
        data.update(mapping)
        data.update(kw)
    
        before = self.before
        for k,v in data.items():
            l = k.lower()
            if k!=l:
                del data[k]
                data[l]=v
                k=l
            before[k] = v[:]

        if data.has_key('dn'):
            self.dn = data['dn'] = normalizeDN(data['dn'])

        if data.has_key('objectclass'):
            self.objectClasses = kjSet([d.lower() for d in data['objectclass']])

        __proceed__(self, data)









    def makeFilter(self, baseFilter=''):
        # go through our search keys and make them filters
        fields = {}
        isKey = self.keyFields.member

        for k,v in self.items():
            if isKey(k): fields[k]=v

        return str(LDAPFilter(baseFilter or '', **fields))
































def normalizeFilter(f,remove=''):

    """Ensure that 'f' is empty or has parens and does not have 'remove' as its operator"""

    f = str(f)
    if not f: return f

    while remove and f.startswith('('+remove):
        f=f[len(remove)+1:-1]

    if not f.startswith('('):
        f = '(%s)' % f

    return f


def wrapFilter(f,op):

    """Ensure that 'f' is empty or has 'op' as its operator"""

    f = str(f)
    if not f: return f
    return '(%s%s)' % (op,f)


def opify(op,*filters):

    """Combine 'filters' using 'op'"""

    filters = filter(None,filters)
    if len(filters)==1: return normalizeFilter(filters[0])
    filters = [normalizeFilter(f,op) for f in filters]
    return wrapFilter(''.join(filters), op)








class LDAPFilter(str):

    def __new__(klass,filter='',**fields):
        fields = ['(%s=%s)' % (k,v) for (k,v) in fields.items()]
        filter=opify('&', filter, *fields)
        return super(LDAPFilter,klass).__new__(klass,filter)

    def __init__(self,filter='', **fields):
        super(LDAPFilter,self).__init__(filter)

    def __and__(self,other):
        return self.__class__(opify('&',self,other))

    def __or__(self,other):
        return self.__class__(opify('|',self,other))

    def __invert__(self):
        if self.startswith('(!'):
            return self[2:-1]
        else:
            return self.__class__('(!%s)' % self)


setupModule()

