"""DataModel test suite"""

from unittest import TestCase, makeSuite, TestSuite
from TW.API import *
from TW.Database import DataModel as DM
from kjbuckets import kjSet
from weakref import WeakValueDictionary

class TestApp:

    from TW.Database.Transactions import TransactionManager

    class WarpCORE(DM.Database):

        class Objects(DM.TypeManager):

            rootTypeName = 'objects'
            
            class object(DM.RecordType):
            
                allKeys = (
                    ('object_id',),
                    ('app_class','app_instance'),
                )
                
            class contact(object):
                pass
                
            class user(object):
                pass
                
            class autobahn_user(contact,user):
                pass


App = TestApp()

wcObjects = App.WarpCORE.Objects



def sortedNames(l):
    names = l[:]
    names.sort()
    return names


class BasicTests(TestCase):

    def checkNames(self):
        assert wcObjects.contact.allTypeNames==kjSet(['contact','object'])
        assert wcObjects.autobahn_user.allTypeNames \
            ==kjSet(['contact','user','object','autobahn_user'])

    def checkSubclasses(self):
        assert wcObjects.object.allSubtypeNames==kjSet(['autobahn_user','contact','object','user'])

    def checkDirects(self):
        assert sortedNames(wcObjects.object.directSubtypeNames)==['contact','user']
        assert sortedNames(wcObjects.contact.directSubtypeNames)==['autobahn_user']
        
    def checkSubtyping(self):
       
        assert wcObjects.contact.isSubtypeOf(wcObjects.object)
        assert not wcObjects.contact.isSubtypeOf(wcObjects.autobahn_user)
        assert not wcObjects.contact.isSubtypeOf(wcObjects.contact)
        assert not wcObjects.contact.isSubtypeOf(wcObjects.user)

        assert wcObjects.autobahn_user.isSubtypeOf(wcObjects.user)
        assert wcObjects.autobahn_user.isSubtypeOf(wcObjects.contact)
        assert wcObjects.autobahn_user.isSubtypeOf(wcObjects.object)

        assert not wcObjects.object.isSubtypeOf(wcObjects.contact)
        assert not wcObjects.object.isSubtypeOf(wcObjects.user)
        assert not wcObjects.object.isSubtypeOf(wcObjects.autobahn_user)

    def checkKeyFields(self):
        assert wcObjects.keyFieldNames == kjSet(['object_id','app_class','app_instance'])




    def checkGetType(self):
        assert wcObjects._getType('contact') is wcObjects.contact

    def checkAllKeys(self):
        assert wcObjects.allKeys==wcObjects.object.allKeys


    def checkNewCache(self):
        assert wcObjects.recordCache \
            is not wcObjects.__class__.recordCache

TestClasses = (
    BasicTests,
)


def test_suite():
    return TestSuite(
        [makeSuite(t,'check') for t in TestClasses]
    )

