"""Test suite for Callbacks module"""

from unittest import TestCase, makeSuite, TestSuite
from TW.API import *
from TW.Callbacks import *


class SimpleTarget:

    def callBack(self, aList):
        aList.append('yes')

class UnweakableTarget(object, SimpleTarget):
    __slots__ = []

    

























class BasicTests(TestCase):

    # Abstract base    
    isWeak = None
    
    def setUp(self):
        self.target = self.targetType()
        self.cb     = Callback(self.target)
        self.aList  = []
        
    def checkValid(self):
        assert self.cb.isValid()

    def checkInvalid(self):
        del self.target
        if self.isWeak:
            assert not self.cb.isValid()
        else:
            assert self.cb.isValid()

    def checkCB(self):
        self.cb(self.aList)
        assert self.aList == ['yes']

    def checkInvalidCB(self):
        del self.target
        self.cb(self.aList)
        if self.isWeak:
            assert self.aList == []
        else:
            assert self.aList == ['yes']

    def checkTarget(self):
        assert self.cb.hasTarget(self.target)
        assert self.cb.hasTarget(self.cb)
        assert not self.cb.hasTarget(self)





    def makeList(self):
        cbl = CallbackList()
        cbl.append(self.cb)
        cbl.append(self.cb)
        cbl.append(self.cb)
        return cbl
        
    def checkListValidity(self):
    
        cbl = self.makeList()
        assert cbl.validCallbacks() == [self.cb]*3
        
        del self.target
        
        if self.isWeak:
            assert cbl.validCallbacks() == []
            assert cbl == []
        else:
            assert cbl.validCallbacks() == [self.cb]*3


    def checkListRemoves(self):

        cbl = self.makeList()
        cbl.remove(self.cb)
        assert cbl == []

        cbl = self.makeList()
        cbl.remove(self.target)
        assert cbl == []


    def checkListCall(self):
        cbl = self.makeList()
        cbl(self.aList)
        assert self.aList == ['yes','yes','yes']





class TestWeak(BasicTests):

    targetType = SimpleTarget
    isWeak     = 1


class TestStrong(BasicTests):

    targetType = UnweakableTarget


class TestDict(BasicTests):

    def setUp(self):
        self.target = {}
        self.cb = Callback(self.target, 'update', {'yes':1})

    def checkCB(self):
        self.cb()
        assert self.target == {'yes':1}

    def checkInvalidCB(self):
        del self.target
        self.cb()
        assert self.cb._getObject() == {'yes':1}


    def checkListCall(self):
    
        cbl = CallbackList(
            [Callback(self.target, 'update', {'yes':1}),
             Callback(self.target, 'update', {'no':2}),
             Callback(self.target, 'update', {'maybe':3}),
            ]
        )
        
        cbl()
        assert self.target == {'yes':1, 'no':2, 'maybe':3}



TestClasses = (
    TestWeak, TestStrong, TestDict,
)

def test_suite():
    return TestSuite(
        [makeSuite(t,'check') for t in TestClasses]
    )


